@@ -16,7 +16,7 @@ our @EXPORT = qw/printW printfW warnW sayW dieW/;
 our @EXPORT_OK = qw//;
 our %EXPORT_TAGS = ('all' => [@EXPORT, @EXPORT_OK]);
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 # default std handle
 my $STD_HANDLE = {
@@ -173,7 +173,7 @@ sub FILENO {}
 __END__
 =head1 NAME
 
-Win32::Unicode::Console.pm - Unicode string to console out
+Win32::Unicode::Console - Unicode string to console out
 
 =head1 SYNOPSIS
 
@@ -195,7 +195,6 @@ Win32::Unicode::Console.pm - Unicode string to console out
 =head1 DESCRIPTION
 
 Win32::Unicode::Console provides Unicode String to console out.
-This module is by default C<printW> and C<warnW> export functions.
 
 This module PerlIO-proof.
 However, when the file is redirected to the C<CORE:: print> and C<CORE:: warn> switches.
@@ -235,4 +234,15 @@ Like die.
 
 Yuji Shimada E<lt>xaicron@cpan.orgE<gt>
 
+=head1 SEE ALSO
+
+L<Win32::Unicode::File>
+
+L<Win32::Unicode::Error>
+
+=head1 LICENSE
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
 =cut
